#[non_exhaustive]pub enum RuntimeError {
Config(String),
Feature(String),
Client(ClientError),
}Expand description
Errors from Runtime operations.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Config(String)
Invalid or unresolvable configuration (e.g. no home directory).
Feature(String)
The requested SpawnStrategy needs a feature that was not compiled in.
Client(ClientError)
A client-side failure surfaced while wiring or probing the daemon.