pub struct Observation {
pub id: String,
pub kind: ObservationKind,
pub content: String,
pub provenance: Map<String, Value>,
pub ts: i64,
pub scope_ids: ScopeIds,
pub redacted: bool,
}Expand description
Atomic, immutable record of an event captured during development.
Mirrors Observation in packages/kindling-core/src/types/observation.ts.
The redacted flag is the only mutable field (via explicit redaction APIs).
Fields
id: Stringkind: ObservationKindcontent: Stringprovenance: Map<String, Value>Source-specific metadata stored as a JSON object.
ts: i64scope_ids: ScopeIdsredacted: boolTrait Implementations
Sourceimpl Clone for Observation
impl Clone for Observation
Sourcefn clone(&self) -> Observation
fn clone(&self) -> Observation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Observation
impl Debug for Observation
Sourceimpl<'de> Deserialize<'de> for Observation
impl<'de> Deserialize<'de> for Observation
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<Observation, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<Observation, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for Observation
impl PartialEq for Observation
Sourcefn eq(&self, other: &Observation) -> bool
fn eq(&self, other: &Observation) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for Observation
impl Serialize for Observation
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for Observation